%global upstream_version 3.1

Name:           ongres-scram
Version:        %(echo %{upstream_version} | sed 's/-/~/g')
Release:        %mkrel 1
Group:          Development/Java
Summary:        Salted Challenge Response Authentication Mechanism (SCRAM) - Java Implementation
License:        BSD-2-Clause
URL:            https://github.com/ongres/scram
Source0:        https://github.com/ongres/scram/archive/%{upstream_version}/scram-%{upstream_version}.tar.gz
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

BuildRequires:  jurand

BuildRequires:  maven-local
BuildRequires:  mvn(com.ongres.stringprep:saslprep)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter)

%description
This is a Java implementation of SCRAM (Salted Challenge Response
Authentication Mechanism) which is part of the family of Simple
Authentication and Security Layer (SASL, RFC 4422) authentication
mechanisms. It is described as part of RFC 5802 and RFC7677.

%package client
Summary:        Client for %{name}
License:        BSD

%description client
This package contains the client for %{name}

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}

%prep
%autosetup -p1 -n "scram-%{upstream_version}"
find \( -name '*.jar' -o -name '*.class' \) -delete

%pom_remove_plugin -r :maven-javadoc-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :flatten-maven-plugin
%pom_remove_plugin -r :maven-invoker-plugin

%pom_remove_dep org.jetbrains:annotations scram-parent

%java_remove_annotations . -s -n NotNull -n Unmodifiable -n Nullable

%mvn_package com.ongres.scram:scram-aggregator __noinstall
%mvn_package com.ongres.scram:scram-parent __noinstall

%pom_xpath_inject 'pom:plugin[pom:artifactId = "maven-jar-plugin"]/pom:configuration/pom:archive' '
<manifestEntries>
  <Multi-Release>true</Multi-Release>
</manifestEntries>
' scram-parent

%build
%mvn_build -s

%install
%mvn_install

%files -f .mfiles-scram-common
%license LICENSE

%files client -f .mfiles-scram-client
%license LICENSE

%files javadoc -f .mfiles-javadoc
%license LICENSE



%changelog
* Fri Aug 30 2024 daviddavid <daviddavid> 3.1-1.mga10
+ Revision: 2092277
- Update to upstream version 3.1

* Mon May 27 2024 daviddavid <daviddavid> 2.1-3.mga10
+ Revision: 2067930
- Rebuilt for java-21-openjdk as system jdk

* Thu Dec 08 2022 daviddavid <daviddavid> 2.1-2.mga9
+ Revision: 1919541
- Remove unnecessary findbugs dependency (#1966792)
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Feb 26 2021 daviddavid <daviddavid> 2.1-1.mga9
+ Revision: 1691997
- Update to version 2.1

* Fri Feb 14 2020 umeabot <umeabot> 1.0.0~beta.2-2.mga8
+ Revision: 1521672
- Mageia 8 Mass Rebuild

* Sat Dec 29 2018 daviddavid <daviddavid> 1.0.0~beta.2-1.mga7
+ Revision: 1346155
- imported package ongres-scram


* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0~beta.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed May 30 2018 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.0.0~beta.2-5
- Remove explicit invocation of maven-javadoc-plugin

* Tue May 22 2018 Pavel Raiskup <praiskup@redhat.com> - 1.0.0~beta.2-4
- BR javadoc maven plugin explicitly
- use nicer Source0 format

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.0~beta.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Nov 27 2017 Pavel Raiskup <praiskup@redhat.com> - 1.0.0~beta.2-2
- drop potential pre-compiled files from release tarball

* Fri Nov 24 2017 Augusto Caringi <acaringi@redhat.com> 1.0.0~beta.2-1
- initial rpm
